==> google_cloud_securitycenter-1.18.2-py2.py3-none-any.whl: google/cloud/securitycenter_v1p1beta1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.securitycenter import gapic_version as package_version

__version__ = package_version.__version__


from .services.security_center import SecurityCenterAsyncClient, SecurityCenterClient
from .types.asset import Asset
from .types.finding import Finding
from .types.folder import Folder
from .types.notification_config import NotificationConfig
from .types.notification_message import NotificationMessage
from .types.organization_settings import OrganizationSettings
from .types.resource import Resource
from .types.run_asset_discovery_response import RunAssetDiscoveryResponse
from .types.security_marks import SecurityMarks
from .types.securitycenter_service import (
    CreateFindingRequest,
    CreateNotificationConfigRequest,
    CreateSourceRequest,
    DeleteNotificationConfigRequest,
    GetNotificationConfigRequest,
    GetOrganizationSettingsRequest,
    GetSourceRequest,
    GroupAssetsRequest,
    GroupAssetsResponse,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAssetsRequest,
    ListAssetsResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    RunAssetDiscoveryRequest,
    SetFindingStateRequest,
    UpdateFindingRequest,
    UpdateNotificationConfigRequest,
    UpdateOrganizationSettingsRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from .types.source import Source

__all__ = (
    "SecurityCenterAsyncClient",
    "Asset",
    "CreateFindingRequest",
    "CreateNotificationConfigRequest",
    "CreateSourceRequest",
    "DeleteNotificationConfigRequest",
    "Finding",
    "Folder",
    "GetNotificationConfigRequest",
    "GetOrganizationSettingsRequest",
    "GetSourceRequest",
    "GroupAssetsRequest",
    "GroupAssetsResponse",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupResult",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "NotificationConfig",
    "NotificationMessage",
    "OrganizationSettings",
    "Resource",
    "RunAssetDiscoveryRequest",
    "RunAssetDiscoveryResponse",
    "SecurityCenterClient",
    "SecurityMarks",
    "SetFindingStateRequest",
    "Source",
    "UpdateFindingRequest",
    "UpdateNotificationConfigRequest",
    "UpdateOrganizationSettingsRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
)

==> google_cloud_securitycenter-1.21.0-py2.py3-none-any.whl: google/cloud/securitycenter_v1p1beta1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.securitycenter_v1p1beta1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.security_center import SecurityCenterAsyncClient, SecurityCenterClient
from .types.asset import Asset
from .types.finding import Finding
from .types.folder import Folder
from .types.notification_config import NotificationConfig
from .types.notification_message import NotificationMessage
from .types.organization_settings import OrganizationSettings
from .types.resource import Resource
from .types.run_asset_discovery_response import RunAssetDiscoveryResponse
from .types.security_marks import SecurityMarks
from .types.securitycenter_service import (
    CreateFindingRequest,
    CreateNotificationConfigRequest,
    CreateSourceRequest,
    DeleteNotificationConfigRequest,
    GetNotificationConfigRequest,
    GetOrganizationSettingsRequest,
    GetSourceRequest,
    GroupAssetsRequest,
    GroupAssetsResponse,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAssetsRequest,
    ListAssetsResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    RunAssetDiscoveryRequest,
    SetFindingStateRequest,
    UpdateFindingRequest,
    UpdateNotificationConfigRequest,
    UpdateOrganizationSettingsRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from .types.source import Source

__all__ = (
    "SecurityCenterAsyncClient",
    "Asset",
    "CreateFindingRequest",
    "CreateNotificationConfigRequest",
    "CreateSourceRequest",
    "DeleteNotificationConfigRequest",
    "Finding",
    "Folder",
    "GetNotificationConfigRequest",
    "GetOrganizationSettingsRequest",
    "GetSourceRequest",
    "GroupAssetsRequest",
    "GroupAssetsResponse",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupResult",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "NotificationConfig",
    "NotificationMessage",
    "OrganizationSettings",
    "Resource",
    "RunAssetDiscoveryRequest",
    "RunAssetDiscoveryResponse",
    "SecurityCenterClient",
    "SecurityMarks",
    "SetFindingStateRequest",
    "Source",
    "UpdateFindingRequest",
    "UpdateNotificationConfigRequest",
    "UpdateOrganizationSettingsRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
)
